@@ -47,11 +47,14 @@ struct _BraseroVolFile {
 
 	struct {
 		gint address_block;
-		gint size_bytes;
+		guint64 size_bytes;
 	} file;
 
 	struct {
 		GList *children;
+
+		/* FIXME: rr_children isn't needed here apparently it could be 
+		 * replaced by address_block. */
 		GList *rr_children;
 	} dir;
 
